/*
 * Copyright (C) 2008-2011 Christian Anthon <anthon@kiku.dk>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * $Id: gnubgstock.h,v 1.7 2019/11/05 21:44:29 plm Exp $
 */

void gnubg_stock_init(void);
#define GNUBG_STOCK_ACCEPT "gnubg-stock-accept"
#define GNUBG_STOCK_ANTI_CLOCKWISE "gnubg-stock-anti-clockwise"
#define GNUBG_STOCK_CLOCKWISE "gnubg-stock-clockwise"
#define GNUBG_STOCK_DOUBLE "gnubg-stock-double"
#define GNUBG_STOCK_END_GAME "gnubg-stock-end-game"
#define GNUBG_STOCK_GO_NEXT_CMARKED "gnubg-stock-go-next-cmarked"
#define GNUBG_STOCK_GO_NEXT_GAME "gnubg-stock-go-next-game"
#define GNUBG_STOCK_GO_NEXT "gnubg-stock-go-next"
#define GNUBG_STOCK_GO_NEXT_MARKED "gnubg-stock-go-next-marked"
#define GNUBG_STOCK_GO_PREV_CMARKED "gnubg-stock-go-prev-cmarked"
#define GNUBG_STOCK_GO_PREV_GAME "gnubg-stock-go-prev-game"
#define GNUBG_STOCK_GO_PREV "gnubg-stock-go-prev"
#define GNUBG_STOCK_GO_PREV_MARKED "gnubg-stock-go-prev-marked"
#define GNUBG_STOCK_HINT "gnubg-stock-hint"
#define GNUBG_STOCK_NEW0 "gnubg-stock-new0"
#define GNUBG_STOCK_NEW11 "gnubg-stock-new11"
#define GNUBG_STOCK_NEW13 "gnubg-stock-new13"
#define GNUBG_STOCK_NEW15 "gnubg-stock-new15"
#define GNUBG_STOCK_NEW17 "gnubg-stock-new17"
#define GNUBG_STOCK_NEW1 "gnubg-stock-new1"
#define GNUBG_STOCK_NEW3 "gnubg-stock-new3"
#define GNUBG_STOCK_NEW5 "gnubg-stock-new5"
#define GNUBG_STOCK_NEW7 "gnubg-stock-new7"
#define GNUBG_STOCK_NEW9 "gnubg-stock-new9"
#define GNUBG_STOCK_OK "gnubg-stock-ok"
#define GNUBG_STOCK_REJECT "gnubg-stock-reject"
#define GNUBG_STOCK_RESIGN "gnubg-stock-resign"
#define GNUBG_STOCK_RESIGNSB "gnubg-stock-resignsb"
#define GNUBG_STOCK_RESIGNSG "gnubg-stock-resignsg"
#define GNUBG_STOCK_RESIGNSN "gnubg-stock-resignsn"
#define GNUBG_STOCK_RUNIT "gnubg-stock-runit"
